@@ -95,9 +95,21 @@ def test_multiple_inherit():
     class C(A, B, EnvConfig):
         a = 4
         c = 5
+        d: str
 
-    assert C._env_fields == ['c']
-    assert C().a == 4
+    logger.debug(C.__fields__)
+    logger.debug({k:v for k,v in C(c=2,d=45)})
+    logger.debug(C(d=45).dict())
+    assert C._env_fields == ['d', 'c']
+    with pytest.raises(ValidationError, match='field required'):
+        assert C().a == 4
+
+    class D(A, B, EnvConfig):
+        a = 4
+        c: str = 5
+        d: str
+
+    assert D._env_fields == ['c', 'd']
 
 def test_file_config(monkeypatch, conf_path, env_path):
     class SubConfig(TemplateConfig):
@@ -157,6 +169,7 @@ def test_file_config(monkeypatch, conf_path, env_path):
     assert not MockConfig._extra_env
     assert MoreEnv._env_fields == ['env_var']
     assert not MoreEnv._extra_env
+    logger.debug(MoreEnv().dict())
 
     class MoreEnv(MockConfig):
         env_var = 99
